@@ -1,4 +1,4 @@
-/* Copyright 2022 VMware, Inc.
+/* Copyright 2023 VMware, Inc.
  * SPDX-License-Identifier: Apache-2.0
  */
 
@@ -164,7 +164,7 @@ static int dns_domain_compare_func(gconstpointer x, gconstpointer y, gpointer us
         if (a->ifindex != b->ifindex)
                 return a->ifindex - b->ifindex;
 
-        return g_str_equal(a->domain, b->domain);
+        return str_eq(a->domain, b->domain);
 }
 
 int dns_domain_add(DNSDomains **h, DNSDomain *a) {
@@ -208,7 +208,7 @@ int add_dns_server_and_domain_to_resolv_conf(DNSServers *dns, char **domains) {
                         _auto_cleanup_ char *pretty = NULL;
                         DNSServer *d =  g_sequence_get(i);
 
-                        r = ip_to_string(d->address.family, &d->address, &pretty);
+                        r = ip_to_str(d->address.family, &d->address, &pretty);
                         if (r < 0)
                                 continue;
 
@@ -284,7 +284,7 @@ int add_dns_server_and_domain_to_resolved_conf(DNSServers *dns, char **domains)
                         _auto_cleanup_ char *pretty = NULL;
                         DNSServer *d =  g_sequence_get(i);
 
-                        r = ip_to_string(d->address.family, &d->address, &pretty);
+                        r = ip_to_str(d->address.family, &d->address, &pretty);
                         if (r < 0)
                                 continue;
 
